==> sql-generator-1.1.2-sample.zip: sql-generator-1.1.2-sample/src/org/sql/sample/function/FunctionSample.java <==
/*
 * SQL Generator
 * 
 * Copyright (C) 2005 Satoshi Nagashiba, All Rights Reserved.
 */
package org.sql.sample.function;

import java.util.Date;
import java.util.LinkedHashMap;
import java.util.Map;

import org.sql.column.SelectColumn;
import org.sql.comparison.Comparisons;
import org.sql.condition.Condition;
import org.sql.exception.GeneratorException;
import org.sql.generator.SelectSql;
import org.sql.generator.Sql;
import org.sql.sample.AbstractSample;
import org.sql.type.Function;
import org.sql.util.GeneratorUtil;


/**
 * ֐gpSQL쐬NX
 * 
 * @author S.Nagashiba
 */
public class FunctionSample extends AbstractSample {

    /**
     * SQL쐬
     * @return SQL
     * @throws GeneratorException SQLO
     */
	protected Sql createSql() throws GeneratorException {
        SelectColumn column = new SelectColumn();
        
        //NVL
        column.append(Function.nvl("COLUMN1", new Integer(-1)), "CLM1");
        
        //NVL2
        column.append(Function.nvl2("COLUMN2", new Integer(0), new Integer(-1)), "CLM2");

        //DECODE
        Map decoMap = new LinkedHashMap();
        decoMap.put("A", "AA");
        decoMap.put("B", "BB");
        column.append(Function.decode("COLUMN3", decoMap, "DEF"), "CLM3");

        //TRUNC
        column.append(Function.trunc(GeneratorUtil.formatExclusion("COLUMN5"), 2), "CLM5");
        
        Condition condition = new Condition();
        condition.and(Comparisons.eq("COLUMN4", new Date()));
        
        return new SelectSql("DUAL", column, condition);
    }
}

==> sql-generator-1.1.3-sample.zip: sql-generator-1.1.3-sample/src/org/sql/sample/function/FunctionSample.java <==
/*
 * SQL Generator
 * 
 * Copyright (C) 2005 Satoshi Nagashiba, All Rights Reserved.
 */
package org.sql.sample.function;

import java.util.Date;
import java.util.LinkedHashMap;
import java.util.Map;

import org.sql.column.SelectColumn;
import org.sql.comparison.Comparisons;
import org.sql.condition.Condition;
import org.sql.exception.GeneratorException;
import org.sql.generator.SelectSql;
import org.sql.generator.Sql;
import org.sql.sample.AbstractSample;
import org.sql.type.Function;
import org.sql.util.GeneratorUtils;


/**
 * ֐gpSQL쐬NX
 * 
 * @author <a href="mailto:nagashiba.satoshi@opcybe.co.jp">Satoshi Nagashiba</a>
 */
public class FunctionSample extends AbstractSample {

    /**
     * SQL쐬
     * @return SQL
     * @throws GeneratorException SQLO
     */
	protected Sql createSql() throws GeneratorException {
        SelectColumn column = new SelectColumn();
        
        //NVL
        column.append(Function.nvl("COLUMN1", new Integer(-1)), "CLM1");
        
        //NVL2
        column.append(Function.nvl2("COLUMN2", new Integer(0), new Integer(-1)), "CLM2");

        //DECODE
        Map decoMap = new LinkedHashMap();
        decoMap.put("A", "AA");
        decoMap.put("B", "BB");
        column.append(Function.decode("COLUMN3", decoMap, "DEF"), "CLM3");

        //TRUNC
        column.append(Function.trunc(GeneratorUtils.formatExclusion("COLUMN5"), 2), "CLM5");
        
        Condition condition = new Condition();
        condition.and(Comparisons.eq("COLUMN4", new Date()));
        
        return new SelectSql("DUAL", column, condition);
    }
}
